gedidb.EarthDataAuthenticator
=============================

.. currentmodule:: gedidb

.. autoclass:: EarthDataAuthenticator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EarthDataAuthenticator.__init__
      ~EarthDataAuthenticator.authenticate
   
   

   
   
   